showSuccessBody property
If this is true successMessage will be rendered as body instead of snack bar
Implementation
final bool showSuccessBody;
If this is true successMessage will be rendered as body instead of snack bar
final bool showSuccessBody;